@@ -24,23 +24,22 @@ NULL
 #' @describeIn bold_italicize_labels_levels Bold labels in gtsummary tables
 #' @export
 bold_labels <- function(x) {
+  updated_call_list <- c(x$call_list, list(bold_labels = match.call()))
   # input checks ---------------------------------------------------------------
   if (!inherits(x, "gtsummary")) {
     stop("Class of 'x' must be 'gtsummary'", call. = FALSE)
   }
 
   # bold labels ----------------------------------------------------------------
-  x$table_header <-
-    x$table_header %>%
-    mutate(
-      bold = case_when(
-        .data$column == "label" & is.na(bold) ~ "row_type == 'label'",
-        .data$column == "label" & !is.na(bold) ~ paste(bold, "row_type == 'label'", sep = " | "),
-        TRUE ~ bold
-      )
+  x <-
+    modify_table_styling(
+      x,
+      columns = "label",
+      rows = .data$row_type == "label",
+      text_format = "bold"
     )
 
-  x$call_list <- c(x$call_list, list(bold_labels = match.call()))
+  x$call_list <- updated_call_list
 
   x
 }
@@ -48,24 +47,22 @@ bold_labels <- function(x) {
 #' @describeIn bold_italicize_labels_levels Bold levels in gtsummary tables
 #' @export
 bold_levels <- function(x) {
+  updated_call_list <- c(x$call_list, list(bold_levels = match.call()))
   # input checks ---------------------------------------------------------------
   if (!inherits(x, "gtsummary")) {
     stop("Class of 'x' must be 'gtsummary'", call. = FALSE)
   }
 
   # bold levels ----------------------------------------------------------------
-  x$table_header <-
-    x$table_header %>%
-    mutate(
-      bold = case_when(
-        .data$column == "label" & is.na(bold) ~ "row_type != 'label'",
-        # appending condition to existing condition
-        .data$column == "label" & !is.na(bold) ~ paste(bold, "row_type != 'label'", sep = " | "),
-        TRUE ~ bold
-      )
+  x <-
+    modify_table_styling(
+      x,
+      columns = "label",
+      rows = .data$row_type != "label",
+      text_format = "bold"
     )
 
-  x$call_list <- c(x$call_list, list(bold_levels = match.call()))
+  x$call_list <- updated_call_list
 
   x
 }
@@ -74,23 +71,22 @@ bold_levels <- function(x) {
 #' @describeIn bold_italicize_labels_levels Italicize labels in gtsummary tables
 #' @export
 italicize_labels <- function(x) {
+  updated_call_list <- c(x$call_list, list(italicize_labels = match.call()))
   # input checks ---------------------------------------------------------------
   if (!inherits(x, "gtsummary")) {
     stop("Class of 'x' must be 'gtsummary'", call. = FALSE)
   }
 
   # italicize labels -----------------------------------------------------------
-  x$table_header <-
-    x$table_header %>%
-    mutate(
-      italic = case_when(
-        .data$column == "label" & is.na(italic) ~ "row_type == 'label'",
-        .data$column == "label" & !is.na(italic) ~ paste(italic, "row_type == 'label'", sep = " | "),
-        TRUE ~ italic
-      )
+  x <-
+    modify_table_styling(
+      x,
+      columns = "label",
+      rows = .data$row_type == "label",
+      text_format = "italic"
     )
 
-  x$call_list <- c(x$call_list, list(italicize_labels = match.call()))
+  x$call_list <- updated_call_list
 
   x
 }
@@ -99,24 +95,22 @@ italicize_labels <- function(x) {
 #' @describeIn bold_italicize_labels_levels Italicize levels in gtsummary tables
 #' @export
 italicize_levels <- function(x) {
+  updated_call_list <- c(x$call_list, list(italicize_levels = match.call()))
   # input checks ---------------------------------------------------------------
   if (!inherits(x, "gtsummary")) {
     stop("Class of 'x' must be 'gtsummary'", call. = FALSE)
   }
 
   # italicize levels -----------------------------------------------------------
-  x$table_header <-
-    x$table_header %>%
-    mutate(
-      italic = case_when(
-        .data$column == "label" & is.na(italic) ~ "row_type != 'label'",
-        # appending condition to existing condition
-        .data$column == "label" & !is.na(italic) ~ paste(italic, "row_type != 'label'", sep = " | "),
-        TRUE ~ italic
-      )
+  x <-
+    modify_table_styling(
+      x,
+      columns = "label",
+      rows = .data$row_type != "label",
+      text_format = "italic"
     )
 
-  x$call_list <- c(x$call_list, list(italicize_levels = match.call()))
+  x$call_list <- updated_call_list
 
   x
 }
