@@ -11,18 +11,18 @@
 #' @author David Hugh-Jones
 assert_package <- function(pkg, fn, version = NULL) {
   if (is.null(version) && !requireNamespace(pkg, quietly = TRUE)) {
-    ui_oops("The {ui_value(pkg)} is required for function {ui_code(fn)}.")
-    usethis::ui_todo("Install the {ui_value(pkg)} package with the code below.")
-    ui_code_block('install.packages("{pkg}")')
+    cli_alert_danger("The {.val {pkg}} package is required for function {.code {fn}}.")
+    cli_ul("Install {.val {pkg}} with the code below.")
+    cli_code(glue('install.packages("{pkg}")'))
     stop("Install required package", call. = FALSE)
   }
 
   if (!is.null(version) &&
-      (!requireNamespace(pkg, quietly = TRUE) ||
-       (requireNamespace(pkg, quietly = TRUE) && utils::packageVersion(pkg) < version))) {
-    ui_oops("The {ui_value(pkg)} v{version} or greater is required for function {ui_code(fn)}.")
-    usethis::ui_todo("Install/update the {ui_value(pkg)} package with the code below.")
-    ui_code_block('install.packages("{pkg}")')
+    (!requireNamespace(pkg, quietly = TRUE) ||
+      (requireNamespace(pkg, quietly = TRUE) && utils::packageVersion(pkg) < version))) {
+    cli_alert_danger("The {.val {pkg}} package {.field v{version}} or greater is required for function {.code {fn}}.")
+    cli_ul("Install/update {.val {pkg}} with the code below.")
+    cli_code(glue('install.packages("{pkg}")'))
     stop("Install required package", call. = FALSE)
   }
 }
@@ -61,9 +61,11 @@ add_expr_after <- function(calls, add_after, expr, new_name = NULL) {
 gts_mapper <- function(x, context) {
   # checking input, and giving informative error msg
   if (!rlang::is_function(x) && !rlang::is_formula(x)) {
-    paste("Expecting a function in argument `{context}`,\n",
-          "e.g. `fun = function(x) style_pvalue(x, digits = 2)`, or\n",
-          "`fun = ~style_pvalue(., digits = 2)`") %>%
+    paste(
+      "Expecting a function in argument `{context}`,\n",
+      "e.g. `fun = function(x) style_pvalue(x, digits = 2)`, or\n",
+      "`fun = ~style_pvalue(., digits = 2)`"
+    ) %>%
       stringr::str_glue()
     rlang::abort()
   }
