@@ -1,5 +1,4 @@
-context("test-tbl_cross")
-testthat::skip_on_cran()
+skip_on_cran()
 
 test_that("tbl_cross- throws error if both `col` and `row`` are not specified", {
   expect_error(
@@ -24,8 +23,10 @@ test_that("tbl_cross- works in character inputs for `col` and `row", {
   col_variable <- "trt"
   row_variable <- "response"
   expect_error(
-    tbl_cross(trial, col = col_variable,
-              row = row_variable),
+    tbl_cross(trial,
+      col = col_variable,
+      row = row_variable
+    ),
     NA
   )
 })
@@ -56,13 +57,17 @@ test_that("tbl_cross- returns errors with bad inputs", {
 # Labels Argument ------------------------------------------------------------
 test_that("tbl_cross- labels work", {
   expect_error(
-    tbl_cross(mtcars, row = am, col = cyl, label = list(am = "AM LABEL",
-                                                        cyl = "New cyl")),
+    tbl_cross(mtcars, row = am, col = cyl, label = list(
+      am = "AM LABEL",
+      cyl = "New cyl"
+    )),
     NA
   )
   expect_error(
-    tbl_cross(mtcars, row = am, col = cyl,
-              label = vars(am) ~ "AM LABEL"),
+    tbl_cross(mtcars,
+      row = am, col = cyl,
+      label = vars(am) ~ "AM LABEL"
+    ),
     NA
   )
 })
@@ -72,7 +77,6 @@ test_that("tbl_cross- statistics argument works", {
   expect_error(
     tbl_cross(trial, statistic = "{p}"),
     NA
-
   )
   expect_error(
     tbl_cross(trial, percent = "cell"),
@@ -86,26 +90,30 @@ test_that("tbl_cross- passing percent without stat works and produces %", {
     NA
   )
   x <- tbl_cross(trial, percent = "cell")
-  expect_equal(sum(str_detect(x$table_body$stat_1, "%"), na.rm = TRUE) > 1,
-               TRUE)
+  expect_equal(
+    sum(str_detect(x$table_body$stat_1, "%"), na.rm = TRUE) > 1,
+    TRUE
+  )
 })
 
 # Missing Argument -------------------------------------------------------------
 test_that("tbl_cross- test 'no' missing throws message", {
   expect_message(
     x <- tbl_cross(trial,
-                   row = trt,
-                   col = response,
-                   missing = "no"),
+      row = trt,
+      col = response,
+      missing = "no"
+    ),
     NULL
   )
 })
 
 test_that("tbl_cross- test no missing omits all NAs", {
   x <- tbl_cross(trial,
-                 row = trt,
-                 col = response,
-                 missing = "no")
+    row = trt,
+    col = response,
+    missing = "no"
+  )
   expect_equal(
     "Unknown" %in% x$table_body$label,
     FALSE
@@ -114,9 +122,10 @@ test_that("tbl_cross- test no missing omits all NAs", {
 
 test_that("tbl_cross- test ifany missing returns Unknown when missing", {
   x <- tbl_cross(trial,
-                 row = response,
-                 col = trt,
-                 missing = "ifany")
+    row = response,
+    col = trt,
+    missing = "ifany"
+  )
   expect_equal(
     "Unknown" %in% x$table_body$label,
     TRUE
@@ -126,9 +135,10 @@ test_that("tbl_cross- test ifany missing returns Unknown when missing", {
 
 test_that("tbl_cross- test 'always' missing returns Unknown even when none", {
   x <- tbl_cross(trial,
-                 row = trt,
-                 col = grade,
-                 missing = "always")
+    row = trt,
+    col = grade,
+    missing = "always"
+  )
   expect_equal(
     "Unknown" %in% x$table_body$label,
     TRUE
@@ -145,9 +155,10 @@ test_that("tbl_cross- works with grouped data (it ungroups it first)", {
 
 # Test Dichotomous -> Categorical  -------------------------------------------
 test_that("tbl_cross- test 'no' missing throws message", {
-
-  data <- data.frame( X = rep(c("Yes", "No"), 3),
-    Y = rep(c("Yes", "No"), each = 3))
+  data <- data.frame(
+    X = rep(c("Yes", "No"), 3),
+    Y = rep(c("Yes", "No"), each = 3)
+  )
 
   table <- data %>% tbl_cross(row = X, col = Y)
 
@@ -156,12 +167,10 @@ test_that("tbl_cross- test 'no' missing throws message", {
     pull(summary_type)
 
   expect_equal(type, "categorical")
-
 })
 
 # Margin Argument  -------------------------------------------
 test_that("tbl_cross- test NULL margin argument", {
-
   margins <- tbl_cross(trial,
     row = trt,
     col = response
